@@ -7,6 +7,9 @@ from twisted.internet.protocol import ClientCreator
 from twisted.internet.protocol import Factory
 from twisted.python import log
 from twisted.internet.interfaces import IConsumer, IPushProducer
+from twisted.internet.error import ConnectionRefusedError
+from twisted.python import log
+
 from katcp import MessageParser, Message, AsyncReply
 from katcp.core import FailReply
 from katcp.server import DeviceLogger, construct_name_filter
@@ -33,13 +36,26 @@ class ShouldReturnMessage(Exception):
 TB_LIMIT = 20
 
 def run_client((host, port), ClientClass, connection_made=None,
-               args=(), errback=None, errback_args=()):
+               args=(), errback=None, errback_args=(), auto_connect=False):
+    def connect_later(failure):
+        if failure is not None:
+            if failure.type is ConnectionRefusedError:
+                reactor.callLater(1, run_client, (host, port), ClientClass,
+                                  connection_made=connection_made, args=args,
+                                  auto_connect=True)
+            else:
+                log.msg("error while connecting")
+                log.err(failure)
+
     cc = ClientCreator(reactor, ClientClass)
     d = cc.connectTCP(host, port)
     if connection_made is not None:
         d.addCallback(connection_made, *args)
     if errback is not None:
+        assert not auto_connect
         d.addErrback(errback, *errback_args)
+    elif auto_connect:
+        d.addErrback(connect_later)
     return d
 
 class KatCP(LineReceiver):
@@ -275,11 +291,14 @@ class KatCPServer(Factory):
     def deregister_client(self, addr):
         del self.clients[addr]
 
-    def stop(self):
+    def stopFactory(self):
         for client in self.clients.values():
             client.transport.loseConnection()
+
+    def stop(self):
         self.port.stopListening()
         if getattr(self, 'production', None):
+            # XXX maybe do it somewhere else???
             reactor.stop()
 
     def buildProtocol(self, addr):
